@@ -61,13 +61,23 @@ export BASEDIR=`pwd`
 # Name of the distribution for the image filename (Defaults to 'debian')
 # export CDNAME=debian
 
-# Building wheezy cd set ...
+# Building $codename cd set ...
 export CODENAME=stretch
 
 # By default use Debian installer packages from $CODENAME
 if [ -z "$DI_CODENAME" ]; then
 	export DI_CODENAME=$CODENAME
 fi
+# If you want backported d-i (e.g. by setting
+# DI_CODENAME=jessie-backports, then you'll almost definitely also
+# want to enable BACKPORTS below as well
+
+# Should we include some packages from backports? If so, point at a
+# file containing a list of binary packages to include here. Packages
+# contained in that list will be chosen by preference from
+# ${CODENAME}-backports rather than just ${CODENAME}, along with
+# dependencies if they're needed as well
+#export BACKPORTS=backports-list
 
 # If set, controls where the d-i components are downloaded from.
 # This may be an url, or "default", which will make it use the default url
@@ -412,7 +422,9 @@ esac
 
 # Add options to wget to include support for the Debian CA, so
 # https://d-i.debian.org et al will work.
-export WGET_OPTS="--ca-directory /etc/ssl/ca-debian/"
+if [ -d "/etc/ssl/ca-debian" ]; then
+	export WGET_OPTS="--ca-directory /etc/ssl/ca-debian/"
+fi
 export WGET="wget $WGET_OPTS"
 
 # Set this to force the Release file(s) to say "stable". Used in first
